from setuptools import setup

setup(
    name='crazehub',
    version='2.8.0',    
    description='A collection of my favorite python scripts',
    url='https://google.com',
    author='Craze',
    author_email='benhershey08@gmail.com',
    license='BSD 2-clause',
    packages=['crazehub'],
    install_requires=[''],

    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',  
        'Operating System :: POSIX :: Linux',        
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)